Analytical transit profiles (Pal 2008)
==================================================

The *palTrans* module implements the analytical transit light-curve
model presented by Pal 2008 [#fPal]_.

**Contents**:

.. toctree::
    :maxdepth: 2
    
    The model classes <pal.rst>
    Taking into account finites integration times <palRebin.rst>
    Adding Boost support <boostsupport.rst>
    Examples <exams.rst>

.. [#fPal] Pal 2008, "Properties of analytic transit light-curve models", 2008MNRAS.390..281P.
